import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import { defaultValueComponents } from '@/components/Form/src/helper';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项tab1*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'fieldCode',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索IP',
    },
  },
  {
    field: 'protectAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
];

/** 列表展示字段tab1*/
export const columns: BasicColumn[] = [
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 120,
    fixed: 'left',
  },
  {
    title: '保护动作',
    dataIndex: 'protectAction',
    width: 120,
    fixed: 'left',
  },
];

/** 新增编辑表单字段tab1*/
export const formSchema: any[] = [
  {
    field: 'ruleType',
    label: '规则类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '规则类型',
      defaultValue: '默认',
      options: [
        { label: '默认', value: '默认' },
        { label: '域名', value: '域名' },
        { label: '特征流量', value: '特征流量' },
        { label: 'URL', value: 'URL' },
        { label: 'API', value: 'API' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择规则类型',
      },
    ],
  },
  {
    field: 'ip',
    label: 'IP',
    component: 'Input',
    componentProps: {
      style: {},
    },
    rules: [
      {
        required: true,
        message: '请输入IP',
      },
    ],
  },
  {
    field: 'fieldName',
    label: '域名',
    component: 'Input',
    componentProps: {
      placeholder: '请输入域名',
      style: {},
    },
    ifShow: ({ values }) => values.ruleType !== undefined && values.ruleType.includes('域名'),
    rules: [
      {
        required: true,
        message: '请输入域名',
      },
    ],
  },
  {
    field: 'featureFlow',
    label: '特征流量',
    component: 'Select',
    componentProps: {
      style: {},
      placeholder: '特征流量',
      options: [
        { label: '下载', value: '下载' },
        { label: '预览', value: '预览' },
      ],
    },
    ifShow: ({ values }) => values.ruleType !== undefined && values.ruleType.includes('特征流量'),
    rules: [
      {
        required: true,
        message: '请选择特征流量',
      },
    ],
  },
  {
    field: 'url',
    label: 'URL',
    component: 'Input',
    componentProps: {
      style: {},
      placeholder: '请输入URL',
    },
    ifShow: ({ values }) => values.ruleType !== undefined && values.ruleType.includes('URL'),
    rules: [
      {
        required: true,
        message: '请输入URL',
      },
    ],
  },

  {
    field: 'protectAction',
    label: '保护动作',
    component: 'Select',
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: '放行', value: '放行' },
        { label: '拒绝', value: '拒绝' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择保护动作',
      },
    ],
  },
];
/** 列表筛选项tab2*/
export const searchFormSchematab2: FormSchema[] = [
  {
    field: 'ip',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索IP',
    },
  },
  {
    field: 'fieldName',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索域名',
    },
  },
  {
    field: 'protectAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
];

/** 列表展示字段tab2*/
export const columnstab2: BasicColumn[] = [
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 120,
    fixed: 'left',
  },
  {
    title: '域名',
    dataIndex: 'fieldName',
    width: 120,
    fixed: 'left',
  },
  {
    title: '保护动作',
    dataIndex: 'protectAction',
    width: 120,
    fixed: 'left',
  },
];

/** 新增编辑表单字段tab2*/
export const formSchematab2: any[] = [
  {
    field: 'ruleType',
    label: '规则类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '规则类型',
      options: [
        { label: '默认', value: '默认' },
        { label: '规则类型1', value: '规则类型1' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择规则类型',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '敏感类型', value: '敏感类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
  {
    field: 'ip',
    label: 'IP',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readOnly: true,
    },
  },
]; /** 列表筛选项tab3*/
export const searchFormSchematab3: FormSchema[] = [
  {
    field: 'fieldCode',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索IP',
    },
  },
  {
    field: 'featureTraffic',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索特征流量',
    },
  },
  {
    field: 'protectAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
];

/** 列表展示字段tab3*/
export const columnstab3: BasicColumn[] = [
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 120,
    fixed: 'left',
  },
  {
    title: '特征流量',
    dataIndex: 'featureTraffic',
    width: 120,
    fixed: 'left',
  },
  {
    title: '保护动作',
    dataIndex: 'protectAction',
    width: 120,
    fixed: 'left',
  },
];

/** 新增编辑表单字段tab3*/
export const formSchematab3: any[] = [
  {
    field: 'ruleType',
    label: '规则类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '规则类型',
      options: [
        { label: '默认', value: '默认' },
        { label: '规则类型1', value: '规则类型1' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择规则类型',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '敏感类型', value: '敏感类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
  {
    field: 'ip',
    label: 'IP',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readOnly: true,
    },
  },
]; /** 列表筛选项tab4*/
export const searchFormSchematab4: FormSchema[] = [
  {
    field: 'fieldCode',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索IP',
    },
  },
  {
    field: 'url',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索URL',
    },
  },
  {
    field: 'protectAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
];

/** 列表展示字段tab4*/
export const columnstab4: BasicColumn[] = [
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 120,
    fixed: 'left',
  },
  {
    title: 'URL',
    dataIndex: 'url',
    width: 120,
    fixed: 'left',
  },
  {
    title: '保护动作',
    dataIndex: 'protectAction',
    width: 120,
    fixed: 'left',
  },
];

/** 新增编辑表单字段tab4*/
export const formSchematab4: any[] = [
  {
    field: 'ruleType',
    label: '规则类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '规则类型',
      options: [
        { label: '默认', value: '默认' },
        { label: '规则类型1', value: '规则类型1' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择规则类型',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '敏感类型', value: '敏感类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
  {
    field: 'ip',
    label: 'IP',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readOnly: true,
    },
  },
];
/** 列表筛选项tab5*/
export const searchFormSchematab5: FormSchema[] = [
  {
    field: 'fieldCode',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索IP',
    },
  },
  {
    field: 'api',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索API',
    },
  },
  {
    field: 'protectAction',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '保护动作',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
];

/** 列表展示字段tab5*/
export const columnstab5: BasicColumn[] = [
  {
    title: 'IP',
    dataIndex: 'ip',
    width: 120,
    fixed: 'left',
  },
  {
    title: 'API',
    dataIndex: 'api',
    width: 120,
    fixed: 'left',
  },
  {
    title: '保护动作',
    dataIndex: 'protectAction',
    width: 120,
    fixed: 'left',
  },
];

/** 新增编辑表单字段tab5*/
export const formSchematab5: any[] = [
  {
    field: 'ruleType',
    label: '规则类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '规则类型',
      options: [
        { label: '默认', value: '默认' },
        { label: '规则类型1', value: '规则类型1' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择规则类型',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '敏感类型', value: '敏感类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
  {
    field: 'ip',
    label: 'IP',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readOnly: true,
    },
  },
];
